<?php
/*
 * Moveto Syntax Plugin.
 *
 * @license  Apache 2 (http://www.apache.org/licenses/LICENSE-2.0)
 * @author   Kazuyuki Matsuda <kazm@shorindo.com>
 */

if (!defined('DOKU_INC')) die();
if (!defined('DOKU_LF')) define('DOKU_LF', "\n");
if (!defined('DOKU_TAB')) define('DOKU_TAB', "\t");
require_once(DOKU_PLUGIN.'syntax.php');

class syntax_plugin_moveto extends DokuWiki_Syntax_Plugin {
	function getInfo() {
        return confToHash(dirname(__FILE__).'/plugin.info.txt');
	}

	function getType() { return 'container'; }

	function getSort() { return 300; }

	function getPType() { return 'block';}

	function connectTo($mode) {
		$this->Lexer->addSpecialPattern('\{\{moveto>.*?\}\}', $mode, 'plugin_moveto');
	}

    /**
     * Handle '{{moveto>...}}' pattern.
     */
	function handle($match, $state, $pos, &$handler) {
		if (preg_match("/^{{moveto>(.*)}}$/", $match, $m)) {
            $param = $m[1];
		}
		return array($state, $param);
    }

    /**
     * Render moveto message.
     */
	function render($mode, &$renderer, $data) {
        global $INFO;

		if($mode == 'xhtml'){
			list($state, $param) = $data;
            $renderer->nocache();
            $opts = array();
            if (preg_match('/^(.*)\?([^\?]*)$/', $param, $matches)) {
                foreach (explode('&', $matches[2]) as $o) {
                    list($key, $val) = explode('=', $o);
                    $opts[$key] = $val;
                }
                $url = $opts['url'] = $matches[1];
            } else {
                $url = $opts['url'] = $param;
            }

            if (!$opts['title']) {
                if (preg_match('/^https?:\/\//u', $url)) { //outside wiki
                    $opts['title'] = $opts['url'];
                } else { //inside wiki
                    $opts['title'] = noNSorNS($opts['url']);
                    if (useHeading('navigation')) {
                        $name = p_get_first_heading($opts['url'],true);
                        if ($name) $opts['title'] = $name;
                    }
                    $url = $opts['url'] = DOKU_URL.cleanID($opts['url']);
                }
            }

            //$this->setmeta($opts);
            $refresh = "";
            if ($opts['auto'] > 0) {
                if ($_SERVER['HTTP_REFERER'] == DOKU_URL.getID())
                    $refresh = $this->getLang("noauto");
                else if ($_REQUEST['redirect'] == 'no')
                    $refresh = $this->getLang("noredirect");
                else
                    $refresh = preg_replace('/\'/', '\'', sprintf($this->getLang('refresh'), $opts['auto']));
            }

            $renderer->doc .=
                '<div>'.
                $this->getLang('moved').
                '<script language="JavaScript">'.
                "<!--\n".
                $this->getscript($refresh).
                "//-->\n".
                '</script>'.
                '<br/><br/>'.
                '<a id="moveto_location" href="'.$url.'">'.hsc($opts['title']).'</a>'.
                '</div>';
        }
    }

    function getscript($refresh) {
        $script = @file_get_contents(dirname(__FILE__).'/refresh.js');
        return preg_replace('/%REFRESH%/', $refresh, $script);
    }
}

